@@ -10,11 +10,10 @@
 
 import abc
 import enum
-import sys
 import typing
-from collections.abc import Sequence
+from collections.abc import Callable, Sequence
 from inspect import Parameter as P, Signature
-from typing import Callable, Generic, List as _List, TypeVar, Union
+from typing import Generic, List as _List, TypeVar, Union
 
 import pytest
 
@@ -25,7 +24,7 @@ from hypothesis.internal.reflection import get_pretty_function_description
 from hypothesis.strategies._internal import types
 from hypothesis.strategies._internal.lazy import LazyStrategy
 from hypothesis.strategies._internal.types import _global_type_lookup
-from hypothesis.strategies._internal.utils import _strategies
+from hypothesis.strategies._internal.utils import _all_strategies
 
 from tests.common.debug import (
     assert_all_examples,
@@ -33,10 +32,16 @@ from tests.common.debug import (
     check_can_generate_examples,
     find_any,
 )
-from tests.common.utils import Why, fails_with, temp_registered, xfail_on_crosshair
+from tests.common.utils import (
+    Why,
+    fails_with,
+    skipif_threading,
+    temp_registered,
+    xfail_on_crosshair,
+)
 
 # we'll continue testing the typing variants until their removal from the stdlib
-# ruff: noqa: UP006, UP035
+# ruff: noqa: UP006, UP035, UP007
 
 types_with_core_strat = {
     type_
@@ -45,7 +50,6 @@ types_with_core_strat = {
 }
 
 
-@pytest.mark.skipif(sys.version_info[:2] >= (3, 14), reason="FIXME-py314")
 def test_generic_sequence_of_integers_may_be_lists_or_bytes():
     strat = st.from_type(Sequence[int])
     find_any(strat, lambda x: isinstance(x, bytes))
@@ -84,11 +88,13 @@ def test_lookup_knows_about_all_core_strategies():
         "timezone_keys",
         "timezones",
     }
-    assert set(_strategies).issuperset(blocklist), blocklist.difference(_strategies)
+    assert set(_all_strategies).issuperset(blocklist), blocklist.difference(
+        _all_strategies
+    )
     found = set()
     for thing in (
         getattr(st, name)
-        for name in sorted(_strategies)
+        for name in sorted(_all_strategies)
         if name in dir(st) and name not in blocklist
     ):
         for n in range(3):
@@ -164,9 +170,6 @@ def test_custom_type_resolution_with_function():
 
 def test_custom_type_resolution_with_function_non_strategy():
     with temp_registered(UnknownType, lambda _: None):
-        # NOTE: For compatibility with Python 3.9's LL(1)
-        # parser, this is written as a nested with-statement,
-        # instead of a compound one.
         with pytest.raises(ResolutionFailed):
             check_can_generate_examples(st.from_type(UnknownType))
         with pytest.raises(ResolutionFailed):
@@ -201,6 +204,7 @@ def test_errors_if_generic_resolves_empty():
             check_can_generate_examples(fails_2)
 
 
+@skipif_threading
 def test_cannot_register_empty():
     # Cannot register and did not register
     with pytest.raises(InvalidArgument):
@@ -337,6 +341,7 @@ def test_issue_2951_regression_two_params():
     "generic",
     (
         Union[str, int],
+        str | int,
         Sequence[Sequence[int]],
         MyGeneric[str],
         Callable[..., str],
@@ -351,9 +356,6 @@ def test_generic_origin_with_type_args(generic, strategy):
     assert generic not in types._global_type_lookup
 
 
-skip_39 = pytest.mark.skipif(sys.version_info[:2] == (3, 9), reason="early version")
-
-
 @pytest.mark.parametrize(
     "generic",
     (
@@ -363,8 +365,8 @@ skip_39 = pytest.mark.skipif(sys.version_info[:2] == (3, 9), reason="early versi
         # you can register types with all generic parameters
         _List[T],
         getattr(typing, "Sequence", None)[T],  # pyupgrade workaround
-        pytest.param(list[T], marks=skip_39),
-        pytest.param(Sequence[T], marks=skip_39),
+        list[T],
+        Sequence[T],
         # User-defined generics should also work
         MyGeneric,
         MyGeneric[T],
